# Кодекс поведения участника

Проект **WB SDK** придерживается Кодекса поведения участника (Contributor Covenant) для обеспечения открытой и уважительной среды. Участники репозитория, issues, Pull Request и связанных каналов соглашаются с изложенными ниже правилами.

---

## Наши обязательства

Мы, как участники, авторы и лидеры обязуемся сделать участие в сообществе свободным от притеснений для всех, независимо от возраста, телосложения, видимых или невидимых ограничений способности, этнической принадлежности, половых признаков, гендерной идентичности и выражения, уровня опыта, образования, социально-экономического статуса, национальности, внешности, расы, касты, цвета, религии, или сексуальной идентичности и ориентации.

Мы обещаем действовать и взаимодействовать таким образом, чтобы вносить вклад в открытое, дружелюбное, многообразное, инклюзивное и здоровое сообщество.

## Наши стандарты

Примеры поведения, создающие условия для благоприятных взаимоотношений включают в себя:

- Ориентирование на то, что лучше подходит для сообщества, а не только для нас лично
- Принятие ответственности, принесение извинений тем, кто пострадал от наших ошибок и извлечение уроков из опыта
- Конструктивная критика и принятие конструктивной критики
- Уважение к чужой точке зрения и опыту
- Проявление доброты и эмпатии к другим участникам проекта

Примеры неприемлемого поведения участников включают в себя:

- Иное поведение, которое обоснованно считать неуместным в профессиональной обстановке
- Публикация личной информации других лиц, например, физического или электронного адреса, без явного разрешения
- Публичное или приватное домогательство
- Троллинг, оскорбительные или уничижительные комментарии, переход на личности или затрагивание политических убеждений
- Использование выражений или изображений сексуального характера и нежелательно сексуальное внимание или домогательство в любой форме

## Обязанности

Лидеры сообщества отвечают за разъяснение и применение наших стандартов приемлемого поведения и будут предпринимать соответствующие и честные меры по исправлению положения в ответ на любое поведение, которое они сочтут неприемлемым, угрожающим, оскорбительным или вредным.

Лидеры сообщества обладают правом и обязанностью удалять, редактировать или отклонять комментарии, коммиты, код, изменения в вики, вопросы и другой вклад, который не совпадает с Кодексом Поведения, и предоставят причины принятого решения, когда сочтут нужным.

## Область применения

Данный Кодекс Поведения применим во всех публичных физических и цифровых пространствах сообщества, а также когда человек официально представляет сообщество в публичных местах. Примеры представления проекта или сообщества включают использование официальной электронной почты, публикации в официальном аккаунте в социальных сетях, или упоминания как представителя в онлайн или офлайн мероприятии.

## Приведение в исполнение

О случаях домогательства, а также оскорбительного или иного неприемлемого поведения можно сообщить мейнтейнерам проекта **в приватном режиме через GitHub** (например, личное сообщение владельцу репозитория). Все жалобы будут рассмотрены и расследованы оперативно и беспристрастно.

Все лидеры сообщества обязаны уважать неприкосновенность частной жизни и личную неприкосновенность автора сообщения.

## Руководство по исполнению

Лидеры сообщества будут следовать следующим Принципам Воздействия в Сообществе, чтобы определить последствия для тех, кого они считают виновными в нарушении данного Кодекса Поведения:

### 1. Исправление

Общественное влияние: Использование недопустимой лексики или другое поведение, считающиеся непрофессиональным или нежелательным в сообществе.

Последствия: Личное, письменное предупреждение от лидеров сообщества, объясняющее суть нарушения и почему такое поведение было неуместно. Лидеры сообщества могут попросить принести публичное извинение.

### 2. Предупреждение

Общественное влияние: Нарушение в результате одного инцидента или серии действий.

Последствия: Предупреждение о последствиях в случае продолжающегося неуместного поведения. На определенное время не допускается взаимодействие с людьми, вовлеченными в инцидент, включая непрошенное взаимодействие с теми, кто обеспечивает соблюдение Кодекса. Это включает в себя избегание взаимодействия в публичных пространствах, а также во внешних каналах, таких как социальные сети. Нарушение этих правил влечет за собой временный или вечный бан.

### 3. Временный бан

Общественное влияние: Серьёзное нарушение стандартов сообщества, включая продолжительное неуместное поведение.

Последствия: Временный запрет (бан) на любое взаимодействие или публичное общение с сообществом на определенный период времени. На этот период не допускается публичное или личное взаимодействие с людьми, вовлеченными в инцидент, включая непрошенное взаимодействие с теми, кто обеспечивает соблюдение Кодекса. Нарушение этих правил влечет за собой вечный бан.

### 4. Вечный бан

Общественное влияние: Демонстрация систематических нарушений стандартов сообщества, включая продолжающееся неуместное поведение, домогательство до отдельных лиц, или проявление агрессии либо пренебрежительного отношения к категориям лиц.

Последствия: Вечный запрет на любое публичное взаимодействие с сообществом.

## Атрибуция

Данный Кодекс Поведения основан на [Contributor Covenant](https://www.contributor-covenant.org/), версии 2.1, доступной по адресу [https://www.contributor-covenant.org/version/2/1/code_of_conduct.html](https://www.contributor-covenant.org/version/2/1/code_of_conduct.html).

Принципы Воздействия в Сообществе были вдохновлены [Mozilla's code of conduct enforcement ladder](https://github.com/mozilla/diversity).

Ответы на общие вопросы о данном кодексе поведения ищите на странице FAQ: [https://www.contributor-covenant.org/faq](https://www.contributor-covenant.org/faq). Переводы доступны по адресу [https://www.contributor-covenant.org/translations](https://www.contributor-covenant.org/translations).
